# Cloud Foundry Dropsonde Protocol for Python

Compiled python generated from the Cloud Foundry Dropsonde Protobuf definition files.

The [Dropsonde Protocol](https://github.com/cloudfoundry/dropsonde-protocol)
is defined here, and this repo provides "protoc" compiled Python and Python3
modules.

## Example

```python
from dropsonde import envelope
from dropsonde import error
from dropsonde import http
from dropsonde import log
from dropsonde import metric
from dropsonde import uuid
```
